@@ -6,7 +6,7 @@ from graphene_django.types import DjangoObjectType
 from graphql_jwt.decorators import login_required
 from rescape_python_helpers import ramda as R
 
-from .django_object_type_revisioned_mixin import DjangoObjectTypeRevisionedMixin
+from .django_object_type_revisioned_mixin import reversion_types, DjangoObjectTypeRevisionedMixin
 from ..django_helpers.write_helpers import increment_prop_until_unique
 from ..graphql_helpers.schema_helpers import input_type_fields, REQUIRE, DENY, CREATE, \
     merge_with_django_properties, input_type_parameters_for_update_or_create, UPDATE, \
@@ -30,7 +30,8 @@ user_fields = merge_with_django_properties(UserType, dict(
     last_name=dict(create=REQUIRE),
     is_staff=dict(),
     is_active=dict(),
-    date_joined=dict(create=DENY, update=DENY)
+    date_joined=dict(create=DENY, update=DENY),
+    **reversion_types
 ))
 
 user_mutation_config = dict(
@@ -83,50 +84,3 @@ class UpdateUser(UpsertUser):
 graphql_update_or_create_user = graphql_update_or_create(user_mutation_config, user_fields)
 graphql_query_users = graphql_query(UserType, user_fields, 'users')
 
-
-
-def graphql_authenticate_user(client, variables):
-    """
-        Executes an authentication with a username and password as variables
-    :param client:
-    :param variables:
-    :return:
-    """
-    return client.execute('''
-mutation TokenAuth($username: String!, $password: String!) {
-  tokenAuth(username: $username, password: $password) {
-    token
-  }
-}''', variables=variables)
-
-
-def graphql_verify_user(client, variables):
-    """
-        Verifies an authentication with token
-    :param client:
-    :param variables: contains a token key that is the token to update
-    :return:
-    """
-    return client.execute('''
-    mutation VerifyToken($token: String!) {
-  verifyToken(token: $token) {
-    payload
-  }
-}''', variables=variables)
-
-
-def graphql_refresh_token(client, variables):
-    """
-        Refreshes an auth token
-    :param client:
-    :param variables: contains a token key that is the token to update
-    :return:
-    """
-    return client.execute('''
-    mutation
-    RefreshToken($token: String!) {
-        refreshToken(token: $token) {
-        token
-    payload
-    }
-}''', variables=variables)
